Skip to contents

Transform a truncated exponential distribution to represent data weighted by a power of w

Usage

transform_truncated_exp(fit, power = 1)

Arguments

fit

A list with the parameters exp, ll, ul, lr, ur

power

The power to raise the weights to

Value

A list with the updated parameters

Examples

fit <- list(alpha = 0.5, ll = 2, ul = 20, lr = 12, ur = 20)
transform_truncated_exp(fit, power = 1)
#> $alpha
#> [1] -0.5
#> 
#> $ll
#> [1] 2
#> 
#> $ul
#> [1] 20
#> 
#> $lr
#> [1] 12
#> 
#> $ur
#> [1] 20
#>