mizerStomach: Using stomach content data in mizer
Source:R/mizerStomach-package.R
mizerStomach-package.RdThis package provides functions to fit distributions to stomach content data and use these distributions to choose parameters for the predation kernel in a mizer model.