Skip to contents

Transform a Gaussian mixture distribution to represent data weighted by a power of w

Usage

transform_gaussian_mixture(fit, power = 1)

Arguments

fit

A list with entries mean, sd and p, each of which is a vector with one entry for each component of the mixture

power

The power to raise the weights to

Value

A list with the updated parameters

Examples

fit <- list(p = c(0.3, 0.7), mean = c(3, 7), sd = c(1, 2))
transform_gaussian_mixture(fit, power = 1)
#> $p
#> [1] 0.2063125 0.7936875
#> 
#> $mean
#> [1] 2 3
#> 
#> $sd
#> [1] 1 2
#>