Transform a Gaussian mixture distribution to represent data weighted by a power of w
Source:R/transform.R
transform_gaussian_mixture.RdTransform a Gaussian mixture distribution to represent data weighted by a power of w
R/transform.R
transform_gaussian_mixture.RdTransform a Gaussian mixture distribution to represent data weighted by a power of w