Transform a truncated exponential distribution to represent data weighted by a power of w
Source:R/transform.R
transform_truncated_exp.RdTransform a truncated exponential distribution to represent data weighted by a power of w
Examples
fit <- list(alpha = 0.5, ll = 2, ul = 20, lr = 12, ur = 20)
transform_truncated_exp(fit, power = 1)
#> $alpha
#> [1] -0.5
#>
#> $ll
#> [1] 2
#>
#> $ul
#> [1] 20
#>
#> $lr
#> [1] 12
#>
#> $ur
#> [1] 20
#>