This is an internal function that checks that the arguments to the fitting
See also
Other validation functions:
validate_fit(),
validate_ppmr_data()
This is an internal function that checks that the arguments to the fitting
Other validation functions:
validate_fit(),
validate_ppmr_data()